@@ -4,7 +4,7 @@
 %
 %    Copyright (C) 2014 SUPELEC
 %
-%    Author: Julien Bect  <julien.bect@supelec.fr>
+%    Author: Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -30,7 +30,7 @@ function ydata = abs (x)
 
 ydata = abs (x.data);
 
-end % function abs
+end % function
 
 
 %!test
