@@ -10,7 +10,7 @@
 %
 %    Copyright (C) 2013, 2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -38,7 +38,7 @@ if strcmp (idx(1).type, '.')
     
     value = get (kreq, idx(1).subs);
     
-    if length(idx) > 1,
+    if length(idx) > 1
         value = subsref(value, idx(2:end));
     end
     
@@ -48,4 +48,4 @@ else
     
 end
 
-end % function subsref
+end % function
