@@ -1,10 +1,15 @@
-% STK_LM_QUADRATIC ... [FIXME: missing documentation]
+% STK_LM_QUADRATIC creates a quadratic linear model object
+%
+% CALL: LM = STK_LM_QUADRATIC ()
+%
+%    creates a quadratic linear model object LM.
 
 % Copyright Notice
 %
+%    Copyright (C) 2017, 2018 CentraleSupelec
 %    Copyright (C) 2012-2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -30,10 +35,7 @@ function lm = stk_lm_quadratic ()
 
 lm = class (struct (), 'stk_lm_quadratic');
 
-end % function stk_lm_quadratic
+end % function
 
 
-% Default constructor
-%!test
-%! lm = stk_lm_quadratic ();
-%! assert (isa (lm, 'stk_lm_quadratic'));
+%!test stk_test_class ('stk_lm_quadratic')
