@@ -4,7 +4,7 @@
 %
 %    Copyright (C) 2012, 2013 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
@@ -32,4 +32,4 @@ a = sprintf(['    ' fmt '    '], varargin{:});
 b = repmat('=', 1, length(a));
 s = sprintf('#%s#\n#%s#\n#%s#\n', b, a, b);
 
-end % function stk_sprintf_framed
+end % function
