@@ -47,7 +47,7 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2016, 2017 CentraleSupelec
+%    Copyright (C) 2016-2018 CentraleSupelec
 %
 %    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
@@ -73,10 +73,6 @@
 
 function x = stk_sampling_sobol (n, dim, box, do_skip)
 
-if nargin > 4
-    stk_error ('Too many input arguments.', 'TooManyInputArgs');
-end
-
 % Default values
 if nargin < 4
     do_skip = false;
