@@ -4,6 +4,7 @@
  *                                                                           *
  * Copyright Notice                                                          *
  *                                                                           *
+ *    Copyright (C) 2017 CentraleSupelec                                     *
  *    Copyright (C) 2014 Supelec                                             *
  *                                                                           *
  *    Author:  Julien Bect  <julien.bect@centralesupelec.fr>                 *
@@ -241,13 +242,15 @@ double bvu (double h, double k, double rho)
   }
   equiv_122 =
   {
-    .1713244923791705, .3607615730481384,
-    .4679139345726904, {0}, .04717533638651177, .1069393259953183,
-    .1600783285433464, .2031674267230659, .2334925365383547,
-    .2491470458134029, {0}, .01761400713915212,
-    .04060142980038694, .06267204833410906, .08327674157670475,
-    .1019301198172404, .1181945319615184, .1316886384491766,
-    .1420961093183821, .1491729864726037, .1527533871307259
+    {.1713244923791705, .3607615730481384, .4679139345726904},
+    {0},
+    {.04717533638651177, .1069393259953183, .1600783285433464,
+     .2031674267230659, .2334925365383547, .2491470458134029},
+    {0},
+    {.01761400713915212, .04060142980038694, .06267204833410906,
+     .08327674157670475, .1019301198172404, .1181945319615184,
+     .1316886384491766, .1420961093183821, .1491729864726037,
+     .1527533871307259}
   };
 
 #define w ((double *)&equiv_122)
@@ -262,13 +265,15 @@ double bvu (double h, double k, double rho)
   }
   equiv_123 =
   {
-    -.9324695142031522, -.6612093864662647,
-    -.238619186083197, {0}, -.9815606342467191, -.904117256370475,
-    -.769902674194305, -.5873179542866171, -.3678314989981802,
-    -.1252334085114692, {0}, -.9931285991850949,
-    -.9639719272779138, -.9122344282513259, -.8391169718222188,
-    -.7463319064601508, -.636053680726515, -.5108670019508271,
-    -.3737060887154196, -.2277858511416451, -.07652652113349733
+    {-.9324695142031522, -.6612093864662647, -.238619186083197},
+    {0},
+    {-.9815606342467191, -.904117256370475, -.769902674194305,
+     -.5873179542866171, -.3678314989981802, -.1252334085114692},
+    {0},
+    {-.9931285991850949, -.9639719272779138, -.9122344282513259,
+     -.8391169718222188, -.7463319064601508, -.636053680726515,
+     -.5108670019508271, -.3737060887154196, -.2277858511416451,
+     -.07652652113349733}
   };
 
 #define x ((double *)&equiv_123)
